@@ -1,7 +1,4 @@
-from django.core.exceptions import ValidationError
 from django.db import models
-from django.db.models.signals import pre_syncdb
-from django.dispatch import receiver
 
 from manager_utils import ManagerUtilsQuerySet, ManagerUtilsManager
 
@@ -13,10 +10,19 @@ class ActivatableQuerySet(ManagerUtilsQuerySet):
     Provides bulk activation/deactivation methods.
     """
     def update(self, *args, **kwargs):
-        ret_val = super(ActivatableQuerySet, self).update(*args, **kwargs)
         if self.model.ACTIVATABLE_FIELD_NAME in kwargs:
+            # Fetch the instances that are about to be updated if they have an activatable flag. This
+            # is because their activatable flag may be changed in the subsequent update, causing us
+            # to potentially lose what this original query referenced
+            updated_instance_ids = list(self.values_list('id', flat=True))
+
+        ret_val = super(ActivatableQuerySet, self).update(*args, **kwargs)
+
+        if self.model.ACTIVATABLE_FIELD_NAME in kwargs:
+            # Refetch the instances that were updated and send them to the activation signal
             model_activations_changed.send(
-                self.model, instances=list(self), is_active=kwargs[self.model.ACTIVATABLE_FIELD_NAME])
+                self.model, instance_ids=updated_instance_ids,
+                is_active=kwargs[self.model.ACTIVATABLE_FIELD_NAME])
         return ret_val
 
     def activate(self):
@@ -73,7 +79,7 @@ class BaseActivatableModel(models.Model):
         # Emit the signal for when the is_active flag is changed
         if is_active_changed:
             model_activations_changed.send(
-                self.__class__, instances=[self], is_active=getattr(self, self.ACTIVATABLE_FIELD_NAME))
+                self.__class__, instance_ids=[self.id], is_active=getattr(self, self.ACTIVATABLE_FIELD_NAME))
 
         return ret_val
 
@@ -86,40 +92,3 @@ class BaseActivatableModel(models.Model):
         else:
             setattr(self, self.ACTIVATABLE_FIELD_NAME, False)
             return self.save(update_fields=[self.ACTIVATABLE_FIELD_NAME])
-
-
-def get_activatable_models():
-    """
-    Gets all models in a project that inherit BaseActivatableModel
-    """
-    return [model for model in models.get_models() if issubclass(model, BaseActivatableModel)]
-
-
-@receiver(pre_syncdb, dispatch_uid='make_sure_activatable_models_cannot_be_cascade_deleted')
-def make_sure_activatable_models_cannot_be_cascade_deleted(*args, **kwargs):
-    """
-    Raises a ValidationError for any ActivatableModel that has ForeignKeys or OneToOneFields that will
-    cause cascading deletions to occur. This function also raises a ValidationError if the activatable
-    model has not defined a Boolean field with the field name defined by the ACTIVATABLE_FIELD_NAME variable
-    on the model.
-    """
-    for model in get_activatable_models():
-        # Verify the activatable model has an activatable boolean field
-        activatable_field = next((
-            f for f in model._meta.fields
-            if f.__class__ == models.BooleanField and f.name == model.ACTIVATABLE_FIELD_NAME
-        ), None)
-        if activatable_field is None:
-            raise ValidationError((
-                'Model {0} is an activatable model. It must define an activatable BooleanField that '
-                'has a field name of model.ACTIVATABLE_FIELD_NAME (which defaults to is_active)'.format(model)
-            ))
-
-        # Ensure all foreign keys and onetoone fields will not result in cascade deletions
-        for field in model._meta.fields:
-            if field.__class__ in (models.ForeignKey, models.OneToOneField):
-                if field.rel.on_delete == models.CASCADE:
-                    raise ValidationError((
-                        'Model {0} is an activatable model. All ForeignKey and OneToOneFields '
-                        'must set on_delete methods to something other than CASCADE (the default)'.format(model)
-                    ))
