@@ -1,13 +1,12 @@
 from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import ValidationError
 from django.db import models
-from django.db.models.signals import pre_syncdb
 from django.test import TestCase, TransactionTestCase
 from django_dynamic_fixture import G
 from mock import patch, MagicMock
 
 from activatable_model import BaseActivatableModel, model_activations_changed
-from activatable_model.models import get_activatable_models
+from activatable_model.validation import get_activatable_models, validate_activatable_models
 from activatable_model.tests.models import ActivatableModel, ActivatableModelWRel, Rel, ActivatableModelWNonDefaultField
 
 
@@ -59,13 +58,13 @@ class ManagerQuerySetTest(BaseMockActivationsSignalHanderTest):
     def test_update_w_is_active(self):
         m1 = G(ActivatableModel, is_active=False)
         m2 = G(ActivatableModel, is_active=False)
-        ActivatableModel.objects.update(char_field='hi', is_active=True)
+        ActivatableModel.objects.filter(is_active=False).update(char_field='hi', is_active=True)
         self.assertEquals(ActivatableModel.objects.filter(char_field='hi', is_active=True).count(), 2)
         self.assertEquals(self.mock_model_activations_changed_handler.call_count, 3)
 
         call_args = self.mock_model_activations_changed_handler.call_args
         self.assertEquals(call_args[1]['is_active'], True)
-        self.assertEquals(set(call_args[1]['instances']), set([m1, m2]))
+        self.assertEquals(set(call_args[1]['instance_ids']), set([m1.id, m2.id]))
         self.assertEquals(call_args[1]['sender'], ActivatableModel)
 
     def test_update_w_is_active_custom(self):
@@ -77,7 +76,7 @@ class ManagerQuerySetTest(BaseMockActivationsSignalHanderTest):
 
         call_args = self.mock_model_activations_changed_handler.call_args
         self.assertEquals(call_args[1]['is_active'], True)
-        self.assertEquals(set(call_args[1]['instances']), set([m1, m2]))
+        self.assertEquals(set(call_args[1]['instance_ids']), set([m1.id, m2.id]))
         self.assertEquals(call_args[1]['sender'], ActivatableModelWNonDefaultField)
 
     def test_activate(self):
@@ -145,7 +144,7 @@ class SaveTest(BaseMockActivationsSignalHanderTest):
         m = G(ActivatableModel, is_active=False)
         call_args = self.mock_model_activations_changed_handler.call_args
         self.assertEquals(call_args[1]['is_active'], False)
-        self.assertEquals(call_args[1]['instances'], [m])
+        self.assertEquals(call_args[1]['instance_ids'], [m.id])
         self.assertEquals(call_args[1]['sender'], ActivatableModel)
 
     def test_save_not_changed(self):
@@ -163,7 +162,7 @@ class SaveTest(BaseMockActivationsSignalHanderTest):
         self.assertEquals(self.mock_model_activations_changed_handler.call_count, 2)
         call_args = self.mock_model_activations_changed_handler.call_args
         self.assertEquals(call_args[1]['is_active'], True)
-        self.assertEquals(call_args[1]['instances'], [m])
+        self.assertEquals(call_args[1]['instance_ids'], [m.id])
         self.assertEquals(call_args[1]['sender'], ActivatableModel)
 
     def test_save_changed_custom(self):
@@ -174,7 +173,7 @@ class SaveTest(BaseMockActivationsSignalHanderTest):
         self.assertEquals(self.mock_model_activations_changed_handler.call_count, 2)
         call_args = self.mock_model_activations_changed_handler.call_args
         self.assertEquals(call_args[1]['is_active'], True)
-        self.assertEquals(call_args[1]['instances'], [m])
+        self.assertEquals(call_args[1]['instance_ids'], [m.id])
         self.assertEquals(call_args[1]['sender'], ActivatableModelWNonDefaultField)
 
 
@@ -202,7 +201,7 @@ class SingleDeleteTest(BaseMockActivationsSignalHanderTest):
         self.assertFalse(ActivatableModel.objects.exists())
 
 
-class PreSyncdbTest(TestCase):
+class ValidateDbTest(TestCase):
     """
     Tests that activatable models are validated properly upon pre_syncdb signal.
     """
@@ -213,11 +212,11 @@ class PreSyncdbTest(TestCase):
 
     def test_all_valid_models(self):
         """
-        Tests emitting the pre_syncdb signal. All models should validate fine.
+        All models should validate fine.
         """
-        pre_syncdb.send(sender=self)
+        validate_activatable_models()
 
-    @patch('activatable_model.models.get_activatable_models')
+    @patch('activatable_model.validation.get_activatable_models')
     def test_activatable_field_is_not_boolean(self, mock_get_activatable_models):
         """
         SET_NULL is a valid option for foreign keys in activatable models.
@@ -233,9 +232,9 @@ class PreSyncdbTest(TestCase):
 
         mock_get_activatable_models.return_value = [NonBooleanModel]
         with self.assertRaises(ValidationError):
-            pre_syncdb.send(sender=self)
+            validate_activatable_models()
 
-    @patch('activatable_model.models.get_activatable_models')
+    @patch('activatable_model.validation.get_activatable_models')
     def test_activatable_field_is_not_defined(self, mock_get_activatable_models):
         """
         SET_NULL is a valid option for foreign keys in activatable models.
@@ -252,9 +251,9 @@ class PreSyncdbTest(TestCase):
 
         mock_get_activatable_models.return_value = [NoValidFieldModel]
         with self.assertRaises(ValidationError):
-            pre_syncdb.send(sender=self)
+            validate_activatable_models()
 
-    @patch('activatable_model.models.get_activatable_models')
+    @patch('activatable_model.validation.get_activatable_models')
     def test_foreign_key_is_null(self, mock_get_activatable_models):
         """
         SET_NULL is a valid option for foreign keys in activatable models.
@@ -269,10 +268,10 @@ class PreSyncdbTest(TestCase):
             ctype = models.ForeignKey(ContentType, null=True, on_delete=models.SET_NULL)
 
         mock_get_activatable_models.return_value = [CascadableModel]
-        pre_syncdb.send(sender=self)
+        validate_activatable_models()
         self.assertEquals(mock_get_activatable_models.call_count, 1)
 
-    @patch('activatable_model.models.get_activatable_models')
+    @patch('activatable_model.validation.get_activatable_models')
     def test_foreign_key_protect(self, mock_get_activatable_models):
         """
         PROTECT is a valid option for foreign keys in activatable models.
@@ -287,10 +286,10 @@ class PreSyncdbTest(TestCase):
             ctype = models.ForeignKey(ContentType, null=True, on_delete=models.PROTECT)
 
         mock_get_activatable_models.return_value = [CascadableModel]
-        pre_syncdb.send(sender=self)
+        validate_activatable_models()
         self.assertEquals(mock_get_activatable_models.call_count, 1)
 
-    @patch('activatable_model.models.get_activatable_models')
+    @patch('activatable_model.validation.get_activatable_models')
     def test_foreign_key_cascade(self, mock_get_activatable_models):
         """
         The default cascade behavior is invalid for activatable models.
@@ -304,9 +303,9 @@ class PreSyncdbTest(TestCase):
 
         mock_get_activatable_models.return_value = [CascadableModel]
         with self.assertRaises(ValidationError):
-            pre_syncdb.send(sender=self)
+            validate_activatable_models()
 
-    @patch('activatable_model.models.get_activatable_models')
+    @patch('activatable_model.validation.get_activatable_models')
     def test_one_to_one_is_null(self, mock_get_activatable_models):
         """
         SET_NULL is a valid option for foreign keys in activatable models.
@@ -321,10 +320,10 @@ class PreSyncdbTest(TestCase):
             ctype = models.OneToOneField(ContentType, null=True, on_delete=models.SET_NULL)
 
         mock_get_activatable_models.return_value = [CascadableModel]
-        pre_syncdb.send(sender=self)
+        validate_activatable_models()
         self.assertEquals(mock_get_activatable_models.call_count, 1)
 
-    @patch('activatable_model.models.get_activatable_models')
+    @patch('activatable_model.validation.get_activatable_models')
     def test_one_to_one_protect(self, mock_get_activatable_models):
         """
         PROTECT is a valid option for foreign keys in activatable models.
@@ -339,10 +338,10 @@ class PreSyncdbTest(TestCase):
             ctype = models.OneToOneField(ContentType, null=True, on_delete=models.PROTECT)
 
         mock_get_activatable_models.return_value = [CascadableModel]
-        pre_syncdb.send(sender=self)
+        validate_activatable_models()
         self.assertEquals(mock_get_activatable_models.call_count, 1)
 
-    @patch('activatable_model.models.get_activatable_models')
+    @patch('activatable_model.validation.get_activatable_models')
     def test_one_to_one_cascade(self, mock_get_activatable_models):
         """
         The default cascade behavior is invalid for activatable models.
@@ -356,4 +355,4 @@ class PreSyncdbTest(TestCase):
 
         mock_get_activatable_models.return_value = [CascadableModel]
         with self.assertRaises(ValidationError):
-            pre_syncdb.send(sender=self)
+            validate_activatable_models()
